@@ -1,13 +1,14 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+# flake8: noqa
 """ Top-level module for intake_esm. """
 # Import intake first to avoid circular imports during discovery.
-import intake  # noqa: F401
+import intake
 from pkg_resources import DistributionNotFound, get_distribution
 
-from .core import esm_datastore  # noqa: F401
+from .core import esm_datastore
+from .utils import show_versions
 
 try:
     __version__ = get_distribution(__name__).version
-except DistributionNotFound:
-    # package is not installed
-    pass
+except DistributionNotFound:  # pragma: no cover
+    __version__ = '0.0.0'  # pragma: no cover
